==> pyterminal_emulator-1.0.2.tar.gz: pyterminal_emulator-1.0.2/README.md <==
<h1 align="center"><a href="https://github.com/ap1311/pyterminal-emulator">pyterminal-emulator</a> - Linux Terminal emulator in any OS</h1>

<p align="center">
  <img src="https://img.shields.io/badge/Author-Aarav%20Shah-purple?style=flat-square">
  <img src="https://img.shields.io/badge/Open%20Source-Yes-cyan?style=flat-square">
  <img src="https://img.shields.io/badge/Made%20in-Bharat-green?colorA=%23ff0000&colorB=%23017e40&style=flat-square">
  <img src="https://img.shields.io/badge/Written%20In-Python-blue?style=flat-square">
</p>

---

## 🌟 Description

**pyterminal-emulator** is a powerful simulation of the Linux command-line environment that runs directly on Windows. It is specially designed for:

- **Students** who cannot install Linux due to lack of knowledge, limited storage, or fear of corrupting their system.
- **Developers** who want to build and test terminal-based tools with real command output.
- **Educators** who want to demonstrate Linux CLI without needing virtual machines or dual-boot setups.

You can run commands like `cp`, `mv`, `chmod`, `git`, `curl`, `bash`, `python`, and many more — just like in a real Linux environment — all within your current operating system.

---

## ✅ Features

- ✅ Simulates real Linux commands with actual command output
- ✅ Includes Git, Curl, Bash, Python, Cat, and more
- ✅ Implements core Unix file operations: `cp`, `mv`, `touch`, `ln`, `chmod`, `find`, etc.
- ✅ Includes advanced tools: `chown`, `chgrp`, `tar`, `gzip`, `zip`, and `umask`
- ✅ Root and guest user roles simulation
- ✅ Python-based and fully customizable
- ✅ Educational and lightweight

---

## 🛠️ Installation

Install from PyPI:

```
pip install pyterminal
```

Or install from source:

```
git clone https://github.com/ap1311/pyterminal-emulator
cd pyterminal
python setup.py install
```

## 📋 Commands Supported

| Command   | Description                       |
| --------- | --------------------------------- |
| `ls`      | List directory contents           |
| `cd`      | Change directory                  |
| `pwd`     | Show current path                 |
| `mkdir`   | Make directory                    |
| `rm`      | Remove file/folder                |
| `whoami`  | Show current user role            |
| `sudo su` | Switch to root user               |
| `cp`      | Copy files                        |
| `mv`      | Move/rename files                 |
| `touch`   | Create empty files                |
| `head`    | Show top lines of a file          |
| `tail`    | Show last lines of a file         |
| `ln`      | Create symbolic links             |
| `find`    | Search files                      |
| `chmod`   | Change file permissions           |
| `chown`   | Change file owner                 |
| `chgrp`   | Change file group                 |
| `umask`   | Set default permission mask       |
| `tar`     | Archive and extract tar files     |
| `gzip`    | Compress and decompress files     |
| `zip`     | Compress files in .zip format     |
| `cat`     | Display file content              |
| `bash`    | Run bash scripts                  |
| `python`  | Run Python scripts                |
| `git`     | Git commands (clone, push, pull…) |
| `curl`    | Fetch from URL                    |
| `wget`    | Download from URL                 |


## ✍️ Example
```
chmod +x script.py
cp file.txt backup/
cd foldername
git clone https://github.com/username/repo.git
bash install.sh
python3 run.py
```

## 🎯 Use Cases
👨‍🎓 Teaching Linux CLI to beginners

💻 Building terminal-based apps without Linux

🧪 Testing Linux command-line tools

🎓 Projects for students and educators

## ⚠️ Disclaimer
This project is for educational purposes only. It does not provide a full Linux shell or kernel. It simulates Linux-like command execution using Python under a controlled environment. It is not meant to replace real Linux systems.

## [~] Find Me on :

- [![Github](https://img.shields.io/badge/Github-Aarav-white?style=for-the-badge&logo=github)](https://github.com/Ap1311/)

- [![Gmail](https://img.shields.io/badge/Gmail-Aarav-red?style=for-the-badge&logo=gmail)](mailto:aaravprogrammers@gmail.com)

- [![Telegram](https://img.shields.io/badge/Telegram-Aarav-skyblue?style=for-the-badge&logo=telegram)](https://t.me/aaravprogrammers)
- [![WhatsApp](https://img.shields.io/badge/WhatsApp-Aarav-green?style=for-the-badge&logo=whatsapp)](https://wa.me/+919429252709)

==> pyterminal_emulator-1.2.1.tar.gz: pyterminal_emulator-1.2.1/README.md <==
<h1 align="center">pyterminal-emulator - Linux Terminal in any OS</h1>

<p align="center">
  <img src="https://img.shields.io/badge/Author-Aarav%20Shah-purple?style=flat-square">
  <img src="https://img.shields.io/badge/Open%20Source-Yes-cyan?style=flat-square">
  <img src="https://img.shields.io/badge/Made%20in-Bharat-green?colorA=%23ff0000&colorB=%23017e40&style=flat-square">
  <img src="https://img.shields.io/badge/Written%20In-Python-blue?style=flat-square">
</p>

---

## 🌟 Description

**pyterminal-emulator** is a powerful simulation of the Linux command-line environment that runs directly on Windows. It is specially designed for:

- **Students** who cannot install Linux due to lack of knowledge, limited storage, or fear of corrupting their system.
- **Developers** who want to build and test terminal-based tools with real command output.
- **Educators** who want to demonstrate Linux CLI without needing virtual machines or dual-boot setups.

You can run commands like `cp`, `mv`, `chmod`, `git`, `curl`, `bash`, `python`, and many more — just like in a real Linux environment — all within your current operating system.

---

## ✅ Features

- ✅ Simulates real Linux commands with actual command output
- ✅ Includes Git, Curl, Bash, Python, Cat, and more
- ✅ Implements core Unix file operations: `cp`, `mv`, `touch`, `ln`, `chmod`, `find`, etc.
- ✅ Includes advanced tools: `chown`, `chgrp`, `tar`, `gzip`, `zip`, and `umask`
- ✅ Root and guest user roles simulation
- ✅ Python-based and fully customizable
- ✅ Educational and lightweight

---

## 🛠️ Installation

Install from PyPI:

```
pip install pyterminal-emulator
```

Or install from source:

```
git clone https://github.com/ap1311/pyterminal-emulator
cd pyterminal-emulator
python setup.py install
```

## 📋 Commands Supported

| Command   | Description                       |
| --------- | --------------------------------- |
| `ls`      | List directory contents           |
| `cd`      | Change directory                  |
| `pwd`     | Show current path                 |
| `mkdir`   | Make directory                    |
| `rm`      | Remove file/folder                |
| `whoami`  | Show current user role            |
| `sudo su` | Switch to root user               |
| `cp`      | Copy files                        |
| `mv`      | Move/rename files                 |
| `touch`   | Create empty files                |
| `head`    | Show top lines of a file          |
| `tail`    | Show last lines of a file         |
| `ln`      | Create symbolic links             |
| `find`    | Search files                      |
| `chmod`   | Change file permissions           |
| `chown`   | Change file owner                 |
| `chgrp`   | Change file group                 |
| `umask`   | Set default permission mask       |
| `tar`     | Archive and extract tar files     |
| `gzip`    | Compress and decompress files     |
| `zip`     | Compress files in .zip format     |
| `cat`     | Display file content              |
| `bash`    | Run bash scripts                  |
| `python`  | Run Python scripts                |
| `git`     | Git commands (clone, push, pull…) |
| `curl`    | Fetch from URL                    |
| `wget`    | Download from URL                 |


## ✍️ Example
```
chmod +x script.py
cp file.txt backup/
cd foldername
git clone https://github.com/username/repo.git
bash install.sh
python3 run.py
```

## 🎯 Use Cases
👨‍🎓 Teaching Linux CLI to beginners

💻 Building terminal-based apps without Linux

🧪 Testing Linux command-line tools

🎓 Projects for students and educators

## ⚠️ Disclaimer
This project is for educational purposes only. It does not provide a full Linux shell or kernel. It simulates Linux-like command execution using Python under a controlled environment. It is not meant to replace real Linux systems.

## [~] Find Me on :

- [![Github](https://img.shields.io/badge/Github-Aarav-white?style=for-the-badge&logo=github)](https://github.com/Ap1311/)

- [![Gmail](https://img.shields.io/badge/Gmail-Aarav-red?style=for-the-badge&logo=gmail)](mailto:aaravprogrammers@gmail.com)

- [![Telegram](https://img.shields.io/badge/Telegram-Aarav-skyblue?style=for-the-badge&logo=telegram)](https://t.me/aaravprogrammers)
- [![WhatsApp](https://img.shields.io/badge/WhatsApp-Aarav-green?style=for-the-badge&logo=whatsapp)](https://wa.me/+919429252709)
